<?php
/**************************************************
  Coppermine 1.5.x Plugin - maskurl
**************************************************/

// Make sure that this file can't be accessed directly, but only from within the Coppermine user interface
if (!defined('IN_COPPERMINE')) {
    die('Not in Coppermine...');
}

include_once('functions.php');                                                  // include plugin subfunctions

// Define plugin actions here
$thisplugin->add_action('plugin_install','maskurl_install');
$thisplugin->add_action('plugin_uninstall','maskurl_uninstall');

// Define plugin filters here
$thisplugin->add_filter('picture_url','maskurl_url');                           // picture_url intercept used to mask URL for all sizes

// Define the plugin's functions here
function maskurl_install() {
    global $CONFIG;
    // Add the config options for the plugin
    cpg_db_query("INSERT IGNORE INTO {$CONFIG['TABLE_CONFIG']} (`name`, `value`) VALUES ('plugin_maskurl_version', '1.0')");
    cpg_db_query("UPDATE {$CONFIG['TABLE_CONFIG']} SET `value` = '1.0' WHERE `name` = 'plugin_maskurl_version'");  // update version if re-install
    cpg_db_query("INSERT IGNORE INTO {$CONFIG['TABLE_CONFIG']} (`name`, `value`) VALUES ('plugin_maskurl_mask_url', '0')");
    cpg_db_query("INSERT IGNORE INTO {$CONFIG['TABLE_CONFIG']} (`name`, `value`) VALUES ('plugin_maskurl_url_prefix', 'index.php?file=maskurl/displayimage')");
    cpg_db_query("INSERT IGNORE INTO {$CONFIG['TABLE_CONFIG']} (`name`, `value`) VALUES ('plugin_maskurl_debug', '0')");
    // alternate value below to execute displayimage.php outside of Coppermine...
    // cpg_db_query("INSERT IGNORE INTO {$CONFIG['TABLE_CONFIG']} (`name`, `value`) VALUES ('plugin_maskurl_url_prefix', 'plugins/maskurl/displayimage.php')");
    $encrypt_keys = maskurl_encrypt_keys($key, $iv);
    if ($encrypt_keys) {
      cpg_db_query("INSERT IGNORE INTO {$CONFIG['TABLE_CONFIG']} (`name`, `value`) VALUES ('plugin_maskurl_encrypt_key', '$key')");
      cpg_db_query("INSERT IGNORE INTO {$CONFIG['TABLE_CONFIG']} (`name`, `value`) VALUES ('plugin_maskurl_encrypt_iv', '$iv')");
      return true;
    }
    else {
      return FALSE;
    }
}


// function to modify pic_row - alter url to call our display page for img to mask URL in html source
function maskurl_url($pic_row) {
    global $CONFIG;
    // copy control flags to local variables
    // if not masking - then return...
    if ((!$CONFIG["plugin_maskurl_mask_url"])) {
      return $pic_row;
    }
    // is this request for a coppermine provided image (such as images/thumbs/thumb_nopic.png when no pics are in an album...)
    if (substr($pic_row["url"], 0, 7) == 'images/') {
      return $pic_row;
    }
    // Work to do - we need to change our prefix snd mask or encrypt if requested.
    $pic_row["url"] = maskurl_set_url($pic_row["url"]);
    return $pic_row;
}


function maskurl_uninstall() {
    global $CONFIG, $lang_errors;
    $superCage = Inspekt::makeSuperCage();
    if (!checkFormToken()) {
        cpg_die(ERROR, $lang_errors['invalid_form_token'], __FILE__, __LINE__);
    }
    // Delete the plugin config records
    cpg_db_query("DELETE FROM {$CONFIG['TABLE_CONFIG']} WHERE name = 'plugin_maskurl_version'");
    cpg_db_query("DELETE FROM {$CONFIG['TABLE_CONFIG']} WHERE name = 'plugin_maskurl_mask_url'");
    cpg_db_query("DELETE FROM {$CONFIG['TABLE_CONFIG']} WHERE name = 'plugin_maskurl_url_prefix'");
    cpg_db_query("DELETE FROM {$CONFIG['TABLE_CONFIG']} WHERE name = 'plugin_maskurl_debug'");
    cpg_db_query("DELETE FROM {$CONFIG['TABLE_CONFIG']} WHERE name = 'plugin_maskurl_encrypt_key'");
    cpg_db_query("DELETE FROM {$CONFIG['TABLE_CONFIG']} WHERE name = 'plugin_maskurl_encrypt_iv'");
    return true;
}
?>